==> thamos-1.16.0.tar.gz: thamos-1.16.0/Documentation/PythonPackageMetadataResponseMetadata.md <==
# PythonPackageMetadataResponseMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**author** | **str** | A string containing the author’s name. |
**author_email** | **str** | A string containing the author’s e-mail address. |
**classifier** | **str** | Each entry is a string giving a single classification value for the distribution. |
**download_url** | **str** | A string containing the URL from which this version of the distribution can be downloaded. |
**home_page** | **str** | A string containing the URL for the distribution’s home page. |
**keywords** | **str** | A list of additional keywords to be used to assist searching for the distribution in a larger catalog.  |
**license** | **str** | Text indicating the license covering the distribution. |
**maintainer** | **str** | A string containing the maintainer’s name at a minimum; additional contact information may be provided.  |
**maintainer_email** | **str** | A string containing the maintainer’s e-mail address. |
**metadata_version** | **str** | Version of the file format. |
**name** | **str** | Name of the distribution. |
**platform** | **str** | A Platform specification describing an operating system supported by the distribution. |
**requires_dist** | **str** | Each entry contains a string naming some other distutils project required by this distribution.  |
**summary** | **str** | A one-line summary of what the distribution does. |
**version** | **str** | version of the distribution. |
**requires_python** | **str** | Python requirements for the distribution. |
**description_content_type** | **str** | Content-Type of description text. |
**project_url** | **str** | URL to project. |
**provides_extra** | **str** | Provided extra of the distribution. |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> thamos-1.23.0.tar.gz: thamos-1.23.0/Documentation/PythonPackageMetadataResponseMetadata.md <==
# PythonPackageMetadataResponseMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**author** | **str** | A string containing the author’s name. |
**author_email** | **str** | A string containing the author’s e-mail address. |
**classifier** | **list[str]** |  |
**download_url** | **str** | A string containing the URL from which this version of the distribution can be downloaded. |
**home_page** | **str** | A string containing the URL for the distribution’s home page. |
**keywords** | **str** | A list of additional keywords to be used to assist searching for the distribution in a larger catalog.  |
**license** | **str** | Text indicating the license covering the distribution. |
**maintainer** | **str** | A string containing the maintainer’s name at a minimum; additional contact information may be provided.  |
**maintainer_email** | **str** | A string containing the maintainer’s e-mail address. |
**metadata_version** | **str** | Version of the file format. |
**name** | **str** | Name of the distribution. |
**platform** | **list[str]** |  |
**requires_dist** | **list[str]** |  |
**summary** | **str** | A one-line summary of what the distribution does. |
**version** | **str** | version of the distribution. |
**requires_python** | **str** | Python requirements for the distribution. |
**description_content_type** | **str** | Content-Type of description text. |
**project_url** | **str** | URL to project. |
**provides_extra** | **str** | Provided extra of the distribution. |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
